<?php
/**
 * Harmony functions
 *
 * What are you looking at here? Here some woo-doo happens to make the theme work.
 * Go and activate the theme on your site!
 *
 */

/**
 * Setup theme features
 *
 * @since 1.0
 */
function harmony_setup() {
	add_theme_support( 'custom-header', array(
		'header-text'            => false,
		'default-image'          => '',
		'height'                 => 250,
		'width'                  => 670,
		'max-width'              => 2000,
		'flex-height'            => true,
		'flex-width'             => true,
		'random-default'         => false,
		'wp-head-callback'       => '',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'cbcbcb',
		'default-image' => get_stylesheet_directory_uri() . '/images/bg.png',
	) );
}
add_action( 'after_setup_theme', 'harmony_setup', 9 );

/**
 * Add theme settings to the Customizer
 *
 * @since 1.0
 */
function harmony_customizer( $customizer ) {
	$customizer->add_setting( 'logo' );
	$customizer->add_control( new WP_Customize_Image_Control( $customizer, 'logo', array(
		'label' => __( 'Logo', 'harmony' ),
		'section' => 'title_tagline',
	) ) );
	$customizer->add_setting( 'accentcolor', array(
		'default' => '#e2a115',
	) );
	$customizer->add_control( new WP_Customize_Color_Control( $customizer, 'accentcolor', array(
		'label' => __( 'Accent Color', 'harmony' ),
		'section' => 'colors',
	) ) );
}
add_action( 'customize_register', 'harmony_customizer' );

/**
 * Register extra widget areas used by Harmony
 *
 * @since 1.0
 */
function harmony_widget_areas() {
	register_sidebar( array(
		'name' => __( 'Top', 'harmony' ),
		'id' => 'top',
		'description' => __( 'Displays on the top right of the page.', 'harmony' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => __( 'Showcase', 'harmony' ),
		'id' => 'showcase',
		'description' => __( 'Displays just above the mainbody. You can add up to 5 widgets in this position.', 'harmony' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	) );
}
add_action( 'widgets_init', 'harmony_widget_areas', 11 );

/**
 * Print internal CSS codes in the head section
 *
 * @since 1.0
 */
function harmony_inline_styles() {

	/* set the logo */
	$logo = get_theme_mod( 'logo' );
	if( '' == $logo ) $logo = trailingslashit( get_stylesheet_directory_uri() ) . 'images/logo.png';
	list( $logo_width, $logo_height ) = @getimagesize( $logo );
	$css = ".site-title a { background: url('{$logo}') no-repeat; width: {$logo_width}px; height: {$logo_height}px; }";

	$header_height = get_custom_header()->height - 40;
	$css .= ".site-title { height: {$header_height}px; }";

	/* Accent color */
	$accent = get_theme_mod( 'accentcolor', '#e2a115' );
	$css .= ".site-title { background: {$accent}; }";

	echo '<style>' . $css . '</style>';
}
add_action( 'wp_head', 'harmony_inline_styles' );

/**
 * Append the search form to the primary menu
 *
 * @since 1.0
 * @return string items
 */
function harmony_nav_search_box( $items, $args ) {
	if( 'primary' == $args->theme_location ) {
		ob_start();
		get_search_form();
		$items .= '<li class="menu-item menu-search">' . ob_get_clean() . '</li>';
	}
	return $items;
}
add_filter( 'wp_nav_menu_primary-navigation_items', 'harmony_nav_search_box', 10, 2 );

/**
 * Returns number of widgets in a widget position
 *
 * @since 1.0
 * @return int
 */
function harmony_position_count( $position ) {
	$sidebar_widgets = wp_get_sidebars_widgets();
	if( isset( $sidebar_widgets[$position] ) ) {
		return count( $sidebar_widgets[$position] );
	}
	return 0;
}

/**
 * Menu fallback
 *
 * @since 1.1
 */
function harmony_menu_fallback() {
	echo sprintf( __( 'Please add a menu to this location: <a href="%s">admin page</a>', 'harmony' ), admin_url( 'nav-menus.php' ) );
}